#[non_exhaustive]pub enum AnimationTrigger {
OnClick,
WithPrevious,
AfterPrevious,
}Expand description
How an animation is triggered relative to other animations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OnClick
Start on mouse click (default).
WithPrevious
Start at the same time as the previous animation.
AfterPrevious
Start after the previous animation finishes.