pub struct GradientFill {
pub stops: Vec<GradientStop>,
pub angle: Option<f64>,
}Expand description
A gradient fill with a sequence of gradient stops.
Fields
stops: Vec<GradientStop>The gradient stops, defining colors and positions along the gradient.
angle: Option<f64>The angle of a linear gradient in degrees (0..360).
None means the angle is inherited or the gradient is non-linear.