pub struct XyChartData { /* private fields */ }Expand description
Accumulates data for XY (scatter) charts.
Example
use pptx::chart::data::XyChartData;
let mut chart_data = XyChartData::new();
let mut series = chart_data.add_series("Measurements");
series.add_data_point(1.0, 2.5);
series.add_data_point(3.0, 4.0);Implementations
Sourceimpl XyChartData
impl XyChartData
Sourcepub fn add_series(&mut self, name: &str) -> &mut XySeriesData
pub fn add_series(&mut self, name: &str) -> &mut XySeriesData
Add a series and return a mutable reference to populate its data points.
Panics
This method will not panic; the internal unwrap() is safe because
an element was just pushed.
Sourcepub fn series(&self) -> &[XySeriesData]
pub fn series(&self) -> &[XySeriesData]
Get the series data.
Sourcepub fn number_format(&self) -> &str
pub fn number_format(&self) -> &str
Get the number format.
Sourcepub fn to_xml(&self, chart_type: XlChartType) -> PptxResult<String>
pub fn to_xml(&self, chart_type: XlChartType) -> PptxResult<String>
Generate chart XML for the given chart type.
Errors
Returns an error if the chart type is unsupported or XML generation fails.