pub struct DataLabels { /* private fields */ }Expand description
Formatting properties for the data labels on a series or data point.
Implementations
Sourceimpl DataLabels
impl DataLabels
Sourcepub const fn show_value(&self) -> bool
pub const fn show_value(&self) -> bool
Whether the value is shown on the data label.
Sourcepub fn set_show_value(&mut self, value: bool)
pub fn set_show_value(&mut self, value: bool)
Set whether the value is shown.
Sourcepub const fn show_category_name(&self) -> bool
pub const fn show_category_name(&self) -> bool
Whether the category name is shown on the data label.
Sourcepub fn set_show_category_name(&mut self, value: bool)
pub fn set_show_category_name(&mut self, value: bool)
Set whether the category name is shown.
Sourcepub const fn show_series_name(&self) -> bool
pub const fn show_series_name(&self) -> bool
Whether the series name is shown on the data label.
Sourcepub fn set_show_series_name(&mut self, value: bool)
pub fn set_show_series_name(&mut self, value: bool)
Set whether the series name is shown.
Sourcepub const fn show_percent(&self) -> bool
pub const fn show_percent(&self) -> bool
Whether the percentage is shown on the data label.
Sourcepub fn set_show_percent(&mut self, value: bool)
pub fn set_show_percent(&mut self, value: bool)
Set whether the percentage is shown.
Sourcepub const fn show_legend_key(&self) -> bool
pub const fn show_legend_key(&self) -> bool
Whether the legend key is shown on the data label.
Sourcepub fn set_show_legend_key(&mut self, value: bool)
pub fn set_show_legend_key(&mut self, value: bool)
Set whether the legend key is shown.
Sourcepub const fn show_bubble_size(&self) -> bool
pub const fn show_bubble_size(&self) -> bool
Whether the bubble size is shown on the data label.
Sourcepub fn set_show_bubble_size(&mut self, value: bool)
pub fn set_show_bubble_size(&mut self, value: bool)
Set whether the bubble size is shown.
Sourcepub const fn show_leader_lines(&self) -> bool
pub const fn show_leader_lines(&self) -> bool
Whether leader lines are shown.
Sourcepub fn set_show_leader_lines(&mut self, value: bool)
pub fn set_show_leader_lines(&mut self, value: bool)
Set whether leader lines are shown.
Sourcepub fn number_format(&self) -> Option<&str>
pub fn number_format(&self) -> Option<&str>
The number format for data label values, or None for default.
Sourcepub fn set_number_format(&mut self, format: Option<&str>)
pub fn set_number_format(&mut self, format: Option<&str>)
Set the number format.
Sourcepub const fn number_format_is_linked(&self) -> bool
pub const fn number_format_is_linked(&self) -> bool
Whether the number format is linked to the source data.
Sourcepub fn set_number_format_is_linked(&mut self, value: bool)
pub fn set_number_format_is_linked(&mut self, value: bool)
Set whether the number format is linked.
Sourcepub const fn position(&self) -> Option<XlDataLabelPosition>
pub const fn position(&self) -> Option<XlDataLabelPosition>
The data label position, or None for the default position.
Sourcepub fn set_position(&mut self, position: Option<XlDataLabelPosition>)
pub fn set_position(&mut self, position: Option<XlDataLabelPosition>)
Set the data label position.